| Title: | R Commander Plug-in for Repeated-Measures ANOVA |
|---|---|
| Description: | R Commander plug-in for repeated-measures and mixed-design ('split-plot') ANOVA. It adds a new menu entry for repeated measures that allows to deal with up to three within-subject factors and optionally with one or several between-subject factors. It also provides supplementary options to oneWayAnova() and multiWayAnova() functions, such as choice of ANOVA type, display of effect sizes and post hoc analysis for multiWayAnova(). |
| Authors: | Arnaud Travert [aut, cre] (ORCID: <https://orcid.org/0000-0002-9579-8910>), Jessica Mange [aut] (ORCID: <https://orcid.org/0000-0001-6279-4721>) |
| Maintainer: | Arnaud Travert <[email protected]> |
| License: | GPL (>=2) |
| Version: | 0.0.6 |
| Built: | 2026-05-21 07:31:36 UTC |
| Source: | https://github.com/atravert/rcmdrplugin.arnova |
This is a minor modification of generalizedLinearModel
where size effects are computed and displayed for logistic regression
generalizedLinearModel_()generalizedLinearModel_()
The Moore data frame has 45 rows and 4 columns.
The data are for subjects in a social-psychological experiment,
who were faced with manipulated disagreement from a partner of either
of low or high status. The subjects could either conform to the
partner's judgment or stick with their own judgment.
MooreMoore
This data frame contains the following columns:
Partner's status. A factor with levels:
high,
low.
Number of conforming responses in 40 critical trials.
F-Scale Categorized.
A factor with levels (note levels out of order):
high,
low,
medium.
Authoritarianism: F-Scale score.
Moore, J. C., Jr. and Krupat, E. (1971) Relationship between source status, authoritarianism and conformity in a social setting. Sociometry 34, 122–134.
Personal communication from J. Moore, Department of Sociology, York University.
Fox, J. (2008) Applied Regression Analysis and Generalized Linear Models, Second Edition. Sage.
Fox, J. and Weisberg, S. (2011) An R Companion to Applied Regression, Second Edition, Sage.
This is a modification of Rcmdr::multiWayAnova()
where supplementary options have been added.
multiWayAnova_()multiWayAnova_()
Options:
'SS type': type of sum of squared, default: type = 2.
See Details in Anova
'Effect size': compute and prints effect size (partial eta squares)
'Summary statistics for groups': prints summary statistics for
groups formed by all combinatuions of factors
'Pairwise comparisons of means': performs post-hoc Tukey's HSD test
on significant (p < .05) or close to significant (p < 0.1) effects.
On OK, the following operations are carried out:
Computes ANOVA using Anova
Computes effect sizes (partial eta squared)
Prints a summary of marginal statistics (count, min, max, mean, ds)
runs post-hoc analysis on significant or close to significant effects
Generates an 'extended' dataset (extension .ext) containing
additionak columns '<factorA.factorB:...>' that allows differentiate
measures from groups or subjects with same factors levels.
This 'extended' dataset is useful for ploting means and post-hoc analysis
None
Anova for the computation of ANOVA
These contrived repeated-measures data are taken from O'Brien and Kaiser (1985). The data are from an imaginary study in which 16 female and male subjects, who are divided into three treatments, are measured at a pretest, postest, and a follow-up session; during each session, they are measured at five occasions at intervals of one hour. The design, therefore, has two between-subject and two within-subject factors.
The contrasts for the treatment factor are set to and
. The contrasts for the gender factor are set to
contr.sum.
OBrienKaiserOBrienKaiser
A data frame with 16 observations on the following 17 variables.
treatmenta factor with levels control A B
gendera factor with levels F M
pre.1pretest, hour 1
pre.2pretest, hour 2
pre.3pretest, hour 3
pre.4pretest, hour 4
pre.5pretest, hour 5
post.1posttest, hour 1
post.2posttest, hour 2
post.3posttest, hour 3
post.4posttest, hour 4
post.5posttest, hour 5
fup.1follow-up, hour 1
fup.2follow-up, hour 2
fup.3follow-up, hour 3
fup.4follow-up, hour 4
fup.5follow-up, hour 5
O'Brien, R. G., and Kaiser, M. K. (1985) MANOVA method for analyzing repeated measures designs: An extensive primer. Psychological Bulletin 97, 316–333, Table 7.
OBrienKaiser contrasts(OBrienKaiser$treatment) contrasts(OBrienKaiser$gender)OBrienKaiser contrasts(OBrienKaiser$treatment) contrasts(OBrienKaiser$gender)
This is a modification of Rcmdr::oneWayAnova()
where supplementary options have been added.
oneWayAnova_()oneWayAnova_()
Options:
'Effect size': compute and prints effect size (partial eta squared)
'Summary statistics for groups': prints summary statistics for
groups formed by the beween subject factor
'Pairwise comparisons of means': performs post-hoc Tukey's HSD test.
On OK, the following operations are carried out:
Computes ANOVA using aov
Computes effect sizes (partial eta squared)
Prints a summary of marginal statistics (count, min, max, mean, ds)
runs post-hoc analysis
None
aov for the computation of ANOVA
The data give the chemical composition of ancient pottery found at four sites in Great Britain. They appear in Hand, et al. (1994), and are used to illustrate MANOVA in the SAS Manual. (Suggested by Michael Friendly.)
PotteryPottery
A data frame with 26 observations on the following 6 variables.
Sitea factor with levels AshleyRails Caldicot IsleThorns Llanedyrn
AlAluminum
FeIron
MgMagnesium
CaCalcium
NaSodium
Hand, D. J., Daly, F., Lunn, A. D., McConway, K. J., and E., O. (1994) A Handbook of Small Data Sets. Chapman and Hall.
PotteryPottery
Dialog box to (i) select the within-subject variables corresponding
to the factors defined in repMeasAnovaSetup, (ii) select the
between-suject factors, (iii) set options and (iv) launch the repeated
measures anova.
repMeasAnova(.withinfactors, .withinlevels)repMeasAnova(.withinfactors, .withinlevels)
.withinfactors |
list of within-subject factors |
.withinlevels |
list of within-subject variables |
Options:
'SS type': type of sum of squares, default: type = 2.
See Details in Anova
'Effect size': compute and prints effect size (partial eta squared)
'Summary statistics for groups': prints summary statistics for
groups formed by all combinations of factors
'Pairwise comparisons of means': performs post-hoc Tukey's HSD test
on significant (p < .05) or close to significant (p < 0.1) effects.
On OK, the following operations are carried out:
Generates a dataset containing complete cases and converted
from 'wide' to 'long' format (extension .cplt.lg), with the following columns added:
'id' (factor): identifies the subjects.
'DV' (numeric): the measure or dependent variable.
'trial' (int): variable that differentiates multiple
measures ('DV') from the same subject ('id').
'<factorA>' (factor): levels of the
within-suject factor A (one column per within subject factor)
'<factorA.factorB:...>' (factor): factor that
differentiates multiple measures from groups or subjects with same factors
levels
This 'long' dataset is useful for ploting means and post-hoc analysis
Computes repeated measure ANOVA using Anova
Computes effect sizes (partial eta squared)
Prints a summary of marginal statistics (count, min, max, mean, ds)
runs post-hoc analysis on significant or close to significant effects
None
Jessica Mange [email protected]
Arnaud Travert [email protected]
repMeasAnovaSetup for the definition of
within factors, Anova for the computation of ANOVA
Dialog box to enter the names and levels of within-factors.
repMeasAnovaSetup()repMeasAnovaSetup()
Up to three factors can be entered. A valid within-factor entry must consist in a syntactically valid name (see make.names) and 2 levels or more.
On OK:
The first valid entries are kept and stored in
.withinfactors and .withinlevels for factor names and
levels, respectively.
The next dialog box (repMeasAnova(.withinfactors, .withinfactors)
is launched.
Jessica Mange [email protected]
Arnaud Travert [email protected]